@@ -1,6 +1,8 @@
 package Mojo::JSON::Pointer;
 use Mojo::Base -base;
 
+use Mojo::Util 'deprecated';
+
 has 'data';
 
 sub contains { shift->_pointer(1, @_) }
@@ -9,8 +11,13 @@ sub get      { shift->_pointer(0, @_) }
 sub new { @_ > 1 ? shift->SUPER::new(data => shift) : shift->SUPER::new }
 
 sub _pointer {
-  my ($self, $contains, $data, $pointer) = @_;
-  ($data, $pointer) = ($self->data, $data) unless defined $pointer;
+  my ($self, $contains, $pointer) = @_;
+  my $data = $self->data;
+
+  # DEPRECATED in Tiger Face!
+  deprecated 'Support for data arguments in Mojo::JSON::Pointer is DEPRECATED'
+    and (($pointer, $data) = ($_[3], $pointer))
+    if defined $_[3];
 
   return $data unless $pointer =~ s!^/!!;
   for my $p ($pointer eq '' ? ($pointer) : (split '/', $pointer)) {
@@ -62,7 +69,7 @@ L<Mojo::JSON::Pointer> implements the following attributes.
   my $data = $pointer->data;
   $pointer = $pointer->data({foo => 'bar'});
 
-Data to be processed.
+Data structure to be processed.
 
 =head1 METHODS
 
@@ -72,40 +79,37 @@ the following new ones.
 =head2 contains
 
   my $bool = $pointer->contains('/foo/1');
-  my $bool = $pointer->contains($data, '/foo/1');
 
-Check if Perl data structure contains a value that can be identified with the
-given JSON Pointer, defaults to using L</data>.
+Check if L</"data"> contains a value that can be identified with the given
+JSON Pointer.
 
   # True
-  $pointer->contains({'♥' => 'mojolicious'}, '/♥');
-  $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/foo');
-  $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/baz/2');
+  Mojo::JSON::Pointer->new({'♥' => 'mojolicious'})->contains('/♥');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5]})->contains('/foo');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5]})->contains('/baz/1');
 
   # False
-  $pointer->contains({'♥' => 'mojolicious'}, '/☃');
-  $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/bar');
-  $pointer->contains({foo => 'bar', baz => [4, 5, 6]}, '/baz/9');
+  Mojo::JSON::Pointer->new({'♥' => 'mojolicious'})->contains('/☃');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5]})->contains('/bar');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5]})->contains('/baz/9');
 
 =head2 get
 
   my $value = $pointer->get('/foo/bar');
-  my $value = $pointer->get($data, '/foo/bar');
 
-Extract value identified by the given JSON Pointer, defaults to using
-L</data>.
+Extract value from L</"data"> identified by the given JSON Pointer.
 
   # "mojolicious"
-  $pointer->get({'♥' => 'mojolicious'}, '/♥');
+  Mojo::JSON::Pointer->new({'♥' => 'mojolicious'})->get('/♥');
 
   # "bar"
-  $pointer->get({foo => 'bar', baz => [4, 5, 6]}, '/foo');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5, 6]})->get('/foo');
 
   # "4"
-  $pointer->get({foo => 'bar', baz => [4, 5, 6]}, '/baz/0');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5, 6]})->get('/baz/0');
 
   # "6"
-  $pointer->get({foo => 'bar', baz => [4, 5, 6]}, '/baz/2');
+  Mojo::JSON::Pointer->new({foo => 'bar', baz => [4, 5, 6]})->get('/baz/2');
 
 =head2 new
 
