@@ -1,8 +1,8 @@
 package Mojolicious::Validator::Validation;
 use Mojo::Base -base;
 
-use Carp 'croak';
-use Scalar::Util 'blessed';
+use Carp         ();
+use Scalar::Util ();
 
 has [qw(csrf_token topic validator)];
 has [qw(input output)] => sub { {} };
@@ -11,10 +11,10 @@ sub AUTOLOAD {
   my $self = shift;
 
   my ($package, $method) = our $AUTOLOAD =~ /^(.+)::(.+)$/;
-  croak "Undefined subroutine &${package}::$method called"
-    unless blessed $self && $self->isa(__PACKAGE__);
+  Carp::croak "Undefined subroutine &${package}::$method called"
+    unless Scalar::Util::blessed $self && $self->isa(__PACKAGE__);
 
-  croak qq{Can't locate object method "$method" via package "$package"}
+  Carp::croak qq{Can't locate object method "$method" via package "$package"}
     unless $self->validator->checks->{$method};
   return $self->check($method => @_);
 }
@@ -92,7 +92,7 @@ sub required {
 }
 
 sub _param {
-  my $value = shift->output->{shift()};
+  return [] unless defined(my $value = shift->output->{shift()});
   return [ref $value eq 'ARRAY' ? @$value : $value];
 }
 
